PlatformException class

Exception thrown when a platform-specific operation fails.

This exception is typically thrown when there's an error in the native platform code or when accessing platform-specific APIs.

Inheritance

Constructors

PlatformException(String message, {String? code})
Creates a new platform exception.
const

Properties

code String?
Platform-specific error code, if available.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited