UnsupportedFeatureException class

Exception thrown when a requested feature is not supported.

This exception indicates that the current platform or device doesn't support the requested functionality.

Inheritance

Constructors

UnsupportedFeatureException(String message, {String? feature})
Creates a new unsupported feature exception.
const

Properties

feature String?
The name of the unsupported feature.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited