PlatformException class
Exception thrown when a platform-specific operation fails.
This exception is typically thrown when there's an error in the native platform code or when accessing platform-specific APIs.
- Inheritance
-
- Object
- DeviceInfoBaseException
- PlatformException
Constructors
- PlatformException(String message, {String? code})
-
Creates a new platform exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited