UnsupportedFeatureException class
Exception thrown when a requested feature is not supported.
This exception indicates that the current platform or device doesn't support the requested functionality.
- Inheritance
-
- Object
- DeviceInfoBaseException
- UnsupportedFeatureException
Constructors
- UnsupportedFeatureException(String message, {String? feature})
-
Creates a new unsupported feature exception.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited