flutter_device_info_plus_web library
Web platform implementation for flutter_device_info_plus
This library provides device information retrieval capabilities for web platforms using browser APIs and user agent parsing.
Classes
- FlutterDeviceInfoPlusPlugin
- Web implementation of FlutterDeviceInfoPlus.
Extension Types
- BatteryManager
- JS interop for the BatteryManager object from the Battery Status API.
- JSNetworkInformation
- JS interop for the NetworkInformation object.
-
Extension for
web.Navigatorto include battery information. -
Extension for
web.Navigatorto include network connection information. -
Extension for
web.Navigatorto include device memory information. -
Extension for
web.Navigatorto include storage manager information. -
Extension for
web.Navigatorto include User Agent Client Hints information. - RTCIceCandidate
- JS interop for the RTCIceCandidate object.
- RTCPeerConnection
- JS interop for the RTCPeerConnection object.
- RTCPeerConnectionIceEvent
- JS interop for the RTCPeerConnectionIceEvent object.
- RTCSessionDescription
- JS interop for the RTCSessionDescription object.
- StorageEstimate
- JS interop for the StorageEstimate object.
- StorageManager
- JS interop for the StorageManager object.
- UABrandVersion
- JS interop for the browser brand and version information.
- UAData
- JS interop for the NavigatorUAData object (Client Hints).
- UADataValues
- JS interop for the high-entropy values returned by UAData.